/** @file launcher.h
 *
 *   The AQUOS Launcher
 *
 *     Copyright (c) 2005, 2006 Sharp Corporation
 *
 */

#if !defined(LAUNCHER_H)
#define LAUNCHER_H

#include <sched.h>
#include <sys/types.h>
#include <sys/syscall.h>

#define USE_THREAD /**< Launcer Ȥꥢ륿ॹåɤưɤ */
#define DEBUG_PROGNAME_POSTFIX "_debug"
#define FIFOFILE "/var/launcher/control"

#define NELMS(array) (sizeof(array)/sizeof((array)[0]))

enum {
  MAX_NUM_OF_ARGS       = 8, 
  MAX_LENGTH_OF_COMMAND = 80,
  MAX_LENGTH_OF_PROCSTR = 256,
  LAUNCHER_SCHED_POLICY = SCHED_FIFO,
  PROGRAMS_SCHED_POLICY = SCHED_OTHER,
  WATCHDOG_INTERVAL     = 10,
  MAX_STACK_SIZE        = 4 * 1024 * 1024,
};


typedef enum {
  Launch_Primary,    /**< λ¨ƥ֡, stdin = console   */
  Launch_Essential,  /**< λ¨ƥ֡, stdin = /dev/null */
  Launch_Repetitive, /**< λץκƵư,   stdin = /dev/null */
  Launch_OneShot,    /**< ưƽ,           stdin = /dev/null */
  Insmod,            /**< insmod ư */
} action_t;

typedef struct
{
  const action_t action;
  int            delay;
  const char*    string;
  const char*    dbgopts;
  pid_t          pid;
  int            pipe_fd[2];
} process_table_t;


static process_table_t the_proctab[] =
{
  //{ Insmod,             0, "/sbin/insmod /root/iLink/brakspear.ko"},
  { Launch_Primary,     0, "/root/abs.out", " -d"},
#if defined(WITH_LNX)
#ifdef G_USE_IRSS
  { Insmod,             0, "/sbin/insmod /root/IrSS/lr388b6-drv.ko"},
  { Insmod,             0, "/sbin/insmod /root/IrSSLnc/irsslauncher_drv.ko"},
#endif
  { Launch_Essential,  50, "/root/executor.out" },
//  { Launch_Essential,  20, "/root/lnx.out" },
//  { Launch_Essential,  21, "/root/carte.out" },
//  { Launch_Essential,  60, "/root/netpro.out" },
  { Launch_Essential,  60, "/root/netss.out" },
  { Launch_OneShot,    40, "/root/dms.out" },
#endif
};


typedef struct
{
  const char* path;
  const char* data;
} proc_set_t;

/* /procؽ񤭹 */
static proc_set_t proc_settab[] =
{
  { "/proc/sys/vm/min_free_kbytes",    "2896" },
  { "/proc/sys/net/core/rmem_max",     "262144" },
  { "/proc/sys/net/core/rmem_default", "262144" },
  { "/proc/sys/net/core/wmem_max",     "262144" },
  { "/proc/sys/net/core/wmem_default", "262144" },
  { "/proc/sys/net/ipv4/tcp_wmem",     "4096 16384 262144" },
  { "/proc/sys/net/ipv4/tcp_rmem",     "4096 87380 262144" },
};


typedef struct
{
  const char* path;
  const mode_t mode;
} dir_set_t;

typedef struct
{
  const char* path;
  const char* data;
  const mode_t mode;
} file_set_t;

static dir_set_t tmp_dir_settab[] =
{
  { "/tmp/wpa_supplicant", 0755 },
};

static file_set_t tmp_file_settab[] =
{
  { "/tmp/wpa_supplicant/wpa_s.conf", "", 0644 },
  { "/tmp/wpa_supplicant/wps.log", "", 0644 },
};

#endif /* LAUNCHER_H */
